#
# spec file for package python-google-auth
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-google-auth
Version:        2.17.3
Release:        150400.6.3.1
Summary:        Google Authentication Library
License:        Apache-2.0
URL:            https://github.com/googleapis/google-auth-library-python
Source:         https://files.pythonhosted.org/packages/source/g/google-auth/google-auth-%{version}.tar.gz
# https://github.com/googleapis/google-auth-library-python/issues/1055
Patch1:         python-google-auth-no-mock.patch
# PATCH-FIX-OPENSUSE urllib3-2.patch -- gh#googleapis/google-auth-library-python#1290
Patch2:         urllib3-2.patch
BuildRequires:  %{python_module Flask}
# START TESTING SECTION
BuildRequires:  %{python_module aiohttp >= 3.6.2}
BuildRequires:  %{python_module cachetools >= 2.0.0}
BuildRequires:  %{python_module freezegun}
BuildRequires:  %{python_module pyOpenSSL >= 20.0.0}
BuildRequires:  %{python_module pyasn1-modules >= 0.2.1}
BuildRequires:  %{python_module pytest-localserver}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pyu2f >= 0.1.5}
BuildRequires:  %{python_module requests >= 2.20.0}
BuildRequires:  %{python_module responses}
BuildRequires:  %{python_module rsa >= 3.1.4}
BuildRequires:  %{python_module setuptools >= 40.3.0}
BuildRequires:  %{python_module six >= 1.9.0}
BuildRequires:  %{python_module urllib3}
# END TESTING SECTION
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-cachetools >= 2.0.0
Requires:       python-cryptography >= 38.0.3
Requires:       python-pyasn1-modules >= 0.2.1
Requires:       python-rsa >= 3.1.4
Requires:       python-setuptools >= 40.3.0
Requires:       python-six >= 1.9.0
Recommends:     python-aiohttp >= 3.6.2
Recommends:     python-pyOpenSSL >= 20.0.0
Recommends:     python-pyu2f >= 0.1.5
Recommends:     python-requests >= 2.20.0
BuildArch:      noarch
%python_subpackages

%description
This library simplifies using Google’s various server-to-server authentication mechanisms to access Google APIs.

%prep
%autosetup -p1 -n google-auth-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# don't test deprecated oauth2client utilities if we don't have it anymore
%pytest --ignore tests/test__oauth2client.py

%files %{python_files}
%license LICENSE
%doc README.rst
%dir %{python_sitelib}/google
%{python_sitelib}/google/auth
%{python_sitelib}/google/oauth2
%{python_sitelib}/google_auth-%{version}*-info
%{python_sitelib}/google_auth-%{version}*-nspkg.pth

%changelog
* Wed May 10 2023 daniel.garcia@suse.com
- Add urllib3-2.patch to support newer urllib3 -- gh#googleapis/google-auth-library-python#1290
- Remove no-python3.patch
- Update to 2.17.3:
  * Add useEmailAzp claim for id token iam flow (#1270) (7a9c6f2)
- 2.17.2:
  * Do not create new JWT credentials if they make the same claims as
    the existing. (#1267) (eebb7b6)
- 2.17.1:
  * Print out reauth plugin error and raise if challenge output is
    None (#1265) (08d22fe)
- 2.17.0:
  * Experimental service account iam endpoint flow for id token
    (#1258) (8ff0de5)
  * Python: Remove aws url validation (#1254) (20a966b)
- 2.16.3:
  * Read both applicationId and relyingPartyId. (#1246) (e125dfe)
- 2.16.2:
  * Call gcloud config get project to get project for user cred
    (#1243) (c078a13)
  * Do not use hardcoded string 'python', when you mean
    sys.executable. (#1233) (91ac8e6)
  * Don't retry if error or error_description is not string (#1241)
    (e2d263a)
  * Improve ADC related errors and warnings (#1237) (2dfa213)
* Fri Apr 21 2023 dmueller@suse.com
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 mcepl@suse.com
- Make calling of %%{sle15modernpython} optional.
* Mon Mar  6 2023 mcepl@suse.com
- Remove conflicts and clean up SPEC file.
* Thu Mar  2 2023 adrian.glaubitz@suse.com
- Update to 2.16.1
  * Add support for python 3.11 (#1212)
  * Remove 3PI config url validation (#1220)
  * Update the docs generator interpreter to unblock documentation build (#1218)
- from version 2.16.0
  * AwsCredentials should not call metadata server if security creds and region
    are retrievable through the environment variables (#1195)
  * Wrap all python built-in exceptions into library excpetions (#1191)
  * Allow get_project_id to take a request (#1203)
  * Make OAUTH2.0 client resistant to string type 'expires_in' responses from
    non-compliant services (#1208)
- Drop obsolete patches
  * ga_python-executable-name.patch
- Refresh patches for new version
  * no-python3.patch
* Wed Feb 22 2023 mcepl@suse.com
- Add no-python3.patch replacing call of the
  string literal 'python3' with sys.executable
  (gh#googleapis/google-auth-library-python!1233).
* Fri Dec  2 2022 adrian.glaubitz@suse.com
- Update to 2.15.0
  * Add api_key credentials (#1184)
  * Introduce a way to provide scopes granted by user (#1189)
  * Allow mtls sts endpoint for external account token urls. (#1185)
  * CI broken by removal of py.path (#1194)
  * Ensure JWT segments have the right types (#1162)
  * Updated the lower bound of interactive timeout and fix the kwarg… (#1182)
* Wed Nov 16 2022 adrian.glaubitz@suse.com
- Update to 2.14.1
  * Apply quota project for compute cred in adc (#1177)
  * Update minimum required version of cryptography in pyopenssl extra (#1176)
  * Validate url domain for aws metadata urls (#1174)
- Update Requires from setup.py
* Tue Nov  8 2022 mcepl@suse.com
- Clean up SPEC file, make rpmlint happy.
* Mon Nov  7 2022 adrian.glaubitz@suse.com
- Update to 2.14.0
  * Add token_info_url to external account credentials (#1168)
  * Read Quota Project from Environment Variable (#1163)
  * Adding more properties to external_account_authorized_user (#1169)
- from version 2.13.0
  * Adds new external account authorized user credentials (#1160)
  * Implement pluggable auth interactive mode (#1131)
  * Introduce the functionality to override token_uri in credentials (#1159)
  * Adding one more pattern to relax the regex check for sts and
    impersonation url endpoints (#1158)
- Refresh patches for new version
  * python-google-auth-no-mock.patch
* Fri Oct 14 2022 adrian.glaubitz@suse.com
- Update to 2.12.0
  * Retry behavior (#1113)
  * Modify RefreshError exception to use gcloud ADC command. (#1149)
  * Revert "Update token refresh threshold from 20 seconds to 5 minutes". (186464b)
- Refresh patches for new version
  * python-google-auth-no-mock.patch
* Thu Sep  8 2022 adrian.glaubitz@suse.com
- Update to 2.11.0
  * add integration tests for configurable token lifespan (#1103)
  * Async certificate retrieving (#1101)
- from version 2.10.0
  * add integration tests for pluggable auth (#1073)
  * support for configurable token lifetime (0dc6a9a)
  * support for configurable token lifetime (#1079)
  * async certificate decoding (#1085)
  * Async system tests were not unwrapping async_generators (#1086)
  * Fix IDTokenCredentials update bug [#1072)
  * make expiration_time optional in response schema (#1091)
  * refactor credential subclass parameters (#1095)
- from version 2.9.1
  * there was a raise missing for throwing exceptions (#1077)
- from version 2.9.0
  * pluggable auth support (#1045)
- from version 2.8.0
  * add experimental GDCH support (#1044)
- Refresh patches for new version
  * python-google-auth-no-mock.patch
* Wed Jun  8 2022 pgajdos@suse.com
- version update to 2.7.0
  [#]# [2.7.0]
  * add experimental enterprise cert support
  * add experimental GDCH support
  * Pluggable auth support
  * validate urls for external accounts
  * pluggable auth support [#995]
  * revert experimental GDCH support
  * fix changelog header to consistent size
  [#]# [2.6.6]
  * silence TypeError during tear down stage
  [#]# [2.6.5]
  * add additional missing import in _default.py
  [#]# [2.6.4]
  * fix missing import in _default.py
- added patches
  fix https://github.com/googleapis/google-auth-library-python/issues/1055
  + python-google-auth-no-mock.patch
* Fri Jun  3 2022 mmachova@suse.com
- Update to 2.6.6
  * fix missing import in _default.py
  * add additional missing import in _default.py
  * silence TypeError during tear down stage
* Thu Apr 14 2022 code@bnavigator.de
- Don't test the converter for the deprecated oauth2client library
* Sat Apr  9 2022 mcepl@suse.com
- Improve %%files to be more restrictive.
* Fri Apr  8 2022 adrian.glaubitz@suse.com
- Update to 2.6.3
  Bug Fixes
  * change requests lib import place (#1010)
  * clean up HTTP session and pool during tear down phase (#1007)
  * pin click version and update sys test creds (#1008)
- from version 2.6.2
  Bug Fixes
  * Rename aws imdsv2 url field and update token lifetime (#982)
  Miscellaneous Chores
  * let release-please finish the release (#991)
- from version 2.6.1
  Bug Fixes
  * Add AWS session token to metadata requests (#958)
- from version 2.6.0
  Features
  * ADC can load an impersonated service account credentials. (#962)
  Bug Fixes
  * revert "feat: add api key support (#826)
* Thu Jan 27 2022 buschmann23@opensuse.org
- Update to 2.5.0
  * ADC can load an impersonated service account credentials. (#965)
- from version 2.4.1
  * fix urrlib3 import (gh#googleapis/google-auth-library-python#953)
- from version 2.4.0
  * add 'py.typed' declaration (#919)
  * add api key support (#826)
  * deps: allow cachetools 5.0 for python 3.7+
    (gh#googleapis/google-auth-library-python#937)
  * fix the message format for metadata server exception
    (gh#googleapis/google-auth-library-python#916)
- from version 2.3.3
  * add fetch_id_token_credentials (gh#googleapis/google-auth-library-python#866)
  * fix error in sign_bytes (gh#googleapis/google-auth-library-python#905)
  * use 'int.to_bytes' and 'int.from_bytes' for py3
    (gh#googleapis/google-auth-library-python#904)
- from version 2.3.2
  * add clock_skew_in_seconds to verify_token functions
    (gh#googleapis/google-auth-library-python#894)
- from version 2.3.1
  * add back python 2.7 for gcloud usage only
    (gh#googleapis/google-auth-library-python#892)
- from version 2.3.0
  * add support for Python 3.10 (#882)
  * ADC with impersonated workforce pools
    (gh#googleapis/google-auth-library-python#877)
- from version 2.2.1
  * disable self signed jwt for domain wide delegation
    (gh#googleapis/google-auth-library-python#873)
- from version 2.2.0
  * add support for workforce pool credentials (#868)
- from version 2.1.0
  * Improve handling of clock skew (#858)
  * add SAML challenge to reauth
    (gh#googleapis/google-auth-library-python#819)
  * disable warning if quota project id provided to auth.default()
    (gh#googleapis/google-auth-library-python#856)
  * rename CLOCK_SKEW and separate client/server user case
    (gh#googleapis/google-auth-library-python#863)
- from version 2.0.2
  * use 'int.to_bytes' rather than deprecated crypto wrapper
    (gh#googleapis/google-auth-library-python#848)
  * use int.from_bytes (gh#googleapis/google-auth-library-python#846)
* Fri Aug 20 2021 adrian.glaubitz@suse.com
- Update to 2.0.1
  * normalize AWS paths correctly on windows (#842)
- from version 2.0.0
  * drop support for Python 2.7 (#778)
  * service account is able to use a private token endpoint (#835)
  * downscoping documentation bugs (#830)
  * Fix missing space in error message. (#821)
  * update user guide/references for downscoped creds (#827)
- from version 1.34.0
  * support refresh callable on google.oauth2.credentials.Credentials (#812)
  * do not use the GAE APIs on gen2+ runtimes (#807)
- from version 1.33.1
  * fallback to source creds expiration in downscoped tokens (#805)
  * revert "feat: service account is able to use a private token endpoint (#784)
- from version 1.33.0
  * define `CredentialAccessBoundary` classes (#793)
  * define `google.auth.downscoped.Credentials` class (#801)
  * service account is able to use a private token endpoint (#784)
  * fix fetch_id_token credential lookup order to match adc (#748)
  * fix code block formatting in 'user-guide.rst' (#794)
- from version 1.32.1
  * avoid leaking sub-session created for '_auth_request' (#789)
- from version 1.32.0
  * allow scopes for self signed jwt (#776)
- from version 1.31.0
  * define useful properties on `google.auth.external_account.Credentials` (#770)
  * avoid deleting items while iterating (#772)
- from version 1.30.2
  * **dependencies:** add urllib3 and requests to aiohttp extra (#755)
  * enforce constraints during unit tests (#760)
  * session object was never used in aiohttp request (#700)
- from version 1.30.1
  * allow user to customize context aware metadata path in _mtls_helper (#754)
  * fix function name in signing error message (#751)
- from version 1.30.0
  * add reauth support to async user credentials for gcloud (#738)
- from version 1.29.0
  * add reauth feature to user credentials for gcloud (#727)
  * Allow multiple audiences for id_token.verify_token (#733)
- from version 1.28.1
  * support custom alg in jwt header for signing (#729)
- from version 1.28.0
  * allow the AWS_DEFAULT_REGION environment variable (#721)
  * expose library version at `google.auth.__version` (#683)
  * fix unit tests so they can work in g3 (#714)
- from version 1.27.1
  * ignore gcloud warning when getting project id (#708)
  * use gcloud creds flow (#705)
- from version 1.27.0
  * workload identity federation support (#698)
  * add pyopenssl as extra dependency (#697)
- from version 1.26.1
  * fix a typo in the user guide (avaiable -> available) (#680)
  * revert workload identity federation support (#691)
- from version 1.26.0
  * workload identity federation support (#686)
- from version 1.25.0
  * support self-signed jwt in requests and urllib3 transports (#679)
  * use self-signed jwt for service account (#665)
- Add patch to fix filename of Python executable in testsuite
  + ga_python-executable-name.patch
- Update BuildRequires from setup.py
* Wed Jan  6 2021 buschmann23@opensuse.org
- Update to 1.24.0
  * add Python 3.9 support, drop Python 3.5 support
    (gh#googleapis/google-auth-library-python#654)
  * avoid losing the original '_include_email' parameter in impersonated
    credentials (gh#googleapis/google-auth-library-python#626)
- from version 1.23.0
  * Add custom scopes for access tokens from the metadata service
    (gh#googleapis/google-auth-library-python#633)
  * remove checks for ancient versions of Cryptography
- from version 1.22.1
  * move aiohttp to extra as it is currently internal surface
    (gh#googleapis/google-auth-library-python#619)
- from version 1.22.0
  * add asyncio based auth flow
    (gh#googleapis/google-auth-library-python#612)
- from version 1.21.3
  * fix expiry for to_json()
    (gh#googleapis/google-auth-library-python#589)
- Skip build for python2 as it is not supported anymore and unit tests
  can not be run because of unsatisfiable dependencies (mock >= 3.6)
- Add urllib3 to the build requirements needed for testing and remove
  cryptography
* Wed Sep 23 2020 dmueller@suse.com
- update to 1.21.2:
  * migrate signBlob to iamcredentials.googleapis.com
* Thu Sep 10 2020 adrian.glaubitz@suse.com
- Update to 1.21.1
  * dummy commit to trigger a auto release (#597)
- from version 1.21.0
  * add GOOGLE_API_USE_CLIENT_CERTIFICATE support (#592)
- from version 1.20.1
  * reduce refresh clock skew to 10 seconds (#581)
  * set Content-Type header in the request to signBlob API
    to avoid Invalid JSON payload error (#439)
- from version 1.20.0
  * Add debug logging that can help with diagnosing auth lib. path (#473)
  * Show the transport exception that happened for GCE Metadata (#474)
  * **packaging:** add support for Python 3.8 (#569), closes (#568)
- from version 1.19.2
  * Revert "fix: migrate signBlob to iamcredentials.googleapis.com"  (#563)
- from version 1.19.1
  * don't add empty quota project  (#560)
- from version 1.19.0
  * add quota project to base credentials class (#546)
  * check 'iss' in `verify_oauth2_token` (#500)
  * migrate signBlob to iamcredentials.googleapis.com (#553)
  * remove 3.4 from supported versions list (#549)
- from version 1.18.0
  * make ``load_credentials_from_file`` a public method (#530)
  * no warning if quota_project_id is given (#537)
* Mon Jun 29 2020 sean.marlow@suse.com
- Add missing pyOpenSSL test dependency which is listed upstream.
* Thu Jun 18 2020 adrian.glaubitz@suse.com
- Update to 1.17.2
  + Bug Fixes
  * narrow acceptable RSA versions to maintain Python 2 compatability (#528)
- from version 1.17.1
  + Features
  * add quota_project_id to service accounts; add with_quota_project methods (#519)
- from version 1.16.1
  + Bug Fixes
  * fix impersonated cred exception doc (#521)
  * replace environment variable GCE_METADATA_ROOT with GCE_METADATA_HOST (#433)
- from version 1.16.0
  + Features
  * add helper func to for default encrypted cert (#514)
  + Bug Fixes
  * fix impersonated cred for gcloud (#516)
* Mon May 25 2020 info@paolostivanin.com
- Update to 1.15.0:
  * encrypted mtls private key support
  * signBytes for impersonated credentials
  * catch exceptions.RefreshError
  * support string type response.data
* Tue Apr 28 2020 tchvatal@suse.com
- Update to 1.14.1:
  * Many bugixes all around
- Remove no longer needed patch:
  * pytest5.patch
- Update the dependencies to match up setup.py and what upstream
  really requires
* Mon Jul 22 2019 tchvatal@suse.com
- Add patch to build with pytest5:
  * pytest5.patch
* Fri Mar 15 2019 tchvatal@suse.com
- Update to 1.6.3:
  * follow rfc 7515 : strip padding from JWS segments #324 (#324)
  * Add retry to _metadata.ping() (#323)
  * Announce deprecation of Python 2.7 (#311)
  * Link all the PRs in CHANGELOG (#307)
  * Automatically refresh impersonated credentials (#304)
  * Add google.auth.impersonated_credentials (#299)
  * Enable static type checking with pytype (#298)
  * Make classifiers in setup.py an array. (#280)
- Drop oauth-no-appengine.patch should not be needed
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Wed Sep 12 2018 tbechtold@suse.com
- update to 1.5.1:
  - Fix check for error text on Python 3.7. (#278)
  - Use new Auth URIs. (#281)
  - Add code-of-conduct document. (#270)
  - Fix some typos in test_urllib3.py (#268)
  - Warn when using user credentials from the Cloud SDK (#266)
  - Add compute engine-based IDTokenCredentials (#236)
  - Corrected some typos (#265)
* Tue May 29 2018 tbechtold@suse.com
- update to 1.4.2:
  - Raise a helpful exception when trying to refresh credentials without
    a refresh token. (#262)
  - Fix links to README and CONTRIBUTING in docs/index.rst. (#260)
  - Fix a typo in credentials.py. (#256)
  - Use pytest instead of py.test per upstream recommendation,
    [#]dropthedot. (#255)
  - Fix typo on exemple of jwt usage (#245)
- Drop Flask from Requires. It is only needed for testing
* Tue May  8 2018 tchvatal@suse.com
- Add patch to not check for oauth appengine which we disable in
  openSUSE:
  * oauth-no-appengine.patch
* Mon May  7 2018 tchvatal@suse.com
- Fix fdupes call and run tests
* Mon May  7 2018 adrian.glaubitz@suse.com
- New upstream release (bsc#1088358)
  + Version 1.4.1
  - Added a check for the cryptography version before attempting to use it.
  + From version 1.4.0
  - Added `cryptography`-based RSA signer and verifier.
  - Added `google.oauth2.service_account.IDTokenCredentials`.
  - Improved documentation around ID Tokens
  + From version 1.3.0
  - Added ``google.oauth2.credentials.Credentials.from_authorized_user_file``.
  - Dropped direct pyasn1 dependency in favor of letting ``pyasn1-modules``
    specify the right version.
  - ``default()`` now checks for the project ID environment var before
    warning about missing project ID.
  - Fixed the docstrings for ``has_scopes()`` and ``with_scopes()``.
  - Fixed example in docstring for ``ReadOnlyScoped``.
  - Made ``transport.requests`` use timeouts and retries
    to improve reliability.
* Sun Nov 19 2017 mc@suse.com
- initial version 1.2.1
